*
*
*
* Replication file SSQ-replication-income.do
* Look Over There. Where? A Compositional Approach to the Modeling of Public Opinion on the Most Important Problem
* Authors: Steven Jokinsky, Christine Lipsmeyer, Andrew Philips, Laron Williams, Guy Whitten
* -------------------------------------------------------------------------
cd "/Users/aqpimac/Dropbox/Lipsmeyer_Philips_Whitten_Williams/SSQ Submission 2023/Final Version/Replication"
use "ssq-replicationdata-income.dta", clear

* ------------------------------ RUN PROGRAMS AND GLOBALS ------------------------------
do "dynsimpieladderplotldv.ado"
do "multidynsimpieldv.ado"

* --------- program to select min aic ---------------
* (for maxlag = 8, after running est table, stats(aic))
cap prog drop minaic
prog define minaic, rclass
	mat aic = r(stats)
	forv i = 1/8 {
		if `i' == 1 {
			loc minaic = aic[1,`i']
			loc lag = `i'
		}
		else {
			if aic[1,`i'] < `minaic' {
				loc minaic = aic[1,`i']
				loc lag = `i'
			}
		}
	}
	di "Ideal lag selection is `lag', as determined via AIC (value of `minaic')"
	return local lag = "`lag'"
end
* -------------------------------------------------

global lreplot "twoway rspike var_pie_ll_lr__lowest25 var_pie_ul_lr__lowest25 sort_pad1, horizontal lcolor(black) || rspike var_pie_ll_lr__second25 var_pie_ul_lr__second25 sort_pad2, horizontal lcolor(black) || rspike var_pie_ll_lr__third25 var_pie_ul_lr__third25 sort_pad3, horizontal lcolor(black) || rspike var_pie_ll_lr__top25 var_pie_ul_lr__top25 sort_pad4, horizontal lcolor(black) || scatter sort_pad1 mid_lr_lowest25, msymbol(T) mcolor("1 108 89") msize(medlarge) || scatter sort_pad2 mid_lr_second25, msymbol(S) mcolor("28 144 153") msize(medlarge) || scatter sort_pad3 mid_lr_third25, msymbol(O) mcolor("103 169 207") msize(medlarge) || scatter sort_pad4 mid_lr_top25, msymbol(D) mcolor("166 189 219") msize(medlarge) xline(0, lcolor(black) lstyle(solid)) yscale(axis(1) noline) xlabel(, grid glcolor(gs15)) plotregion(style(none)) legend(order(5 "Bottom 25%" 6 "Second 25%" 7 "Third 25%" 8 "Top 25%") ) xtitle("Predicted Change from Baseline")  ylabel(1 "Crime" 2 "Social Welfare" 3 "Intl. Affairs" 4 "Culture" 5 "Other" 6 "Economic Issues", angle(45)) ysize(5) title("Long-Run")"

global dvs1 "code11_1_perc_i_code1 code6_1_perc_i_code1 code14_1_perc_i_code1  code19_1_perc_i_code1 code21_1_perc_i_code1" // top 25

global dvs2 "code11_2_perc_i_code1 code6_2_perc_i_code1 code14_2_perc_i_code1  code19_2_perc_i_code1 code21_2_perc_i_code1" // third 25

global dvs3 "code11_3_perc_i_code1 code6_3_perc_i_code1 code14_3_perc_i_code1  code19_3_perc_i_code1 code21_3_perc_i_code1" // second 25

global dvs4 "code11_4_perc_i_code1 code6_4_perc_i_code1 code14_4_perc_i_code1  code19_4_perc_i_code1 code21_4_perc_i_code1" // lowest 25
* -------------------------------------------------


/* Here's the order of incomes:

cap1_4_perc    Top 25%
cap1_3_perc    third 25%
cap1_2_perc    Next 25%
cap1_1_perc    Lowest 25%

*/ 
tsset tsm

set seed 2789099

gen fakeid = 1 // need to trick dynsimpiecstsldv into thinking we have csts data
xtset fakeid tsm


* --------------------------
* Figure 6
* Stable, all constant expected value across types
* --------------------------
* here's top25
multidynsimpieldv lpost911 lgdp_growth nytmacrol1 licb_total linflation  nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) t(4) id(fakeid) shock(0) shockvar(lch_gasprice)  saving("dynsimpie_top25")
* here's top25
multidynsimpieldv lpost911 lgdp_growth nytmacrol1 licb_total linflation  nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs2) t(4) id(fakeid) shock(0) shockvar(lch_gasprice)  saving("dynsimpie_third25")
* here's top25
multidynsimpieldv lpost911 lgdp_growth nytmacrol1 licb_total linflation  nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs3) t(4) id(fakeid) shock(0) shockvar(lch_gasprice)  saving("dynsimpie_second25")
* here's top25
multidynsimpieldv lpost911 lgdp_growth nytmacrol1 licb_total linflation  nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs4) t(4) id(fakeid) shock(0) shockvar(lch_gasprice)  saving("dynsimpie_lowest25")

preserve
use "dynsimpie_top25", clear
foreach var of varlist var1_pie_ll_ - mid6 {
	rename `var' `var'_top25
}
joinby time using "dynsimpie_third25"
foreach var of varlist var1_pie_ll_ - mid6 {
	rename `var' `var'_third25
}
joinby time using "dynsimpie_second25"
foreach var of varlist var1_pie_ll_ - mid6 {
	rename `var' `var'_second25
}
joinby time using "dynsimpie_lowest25"
foreach var of varlist var1_pie_ll_ - mid6 {
	rename `var' `var'_lowest25
}
keep if time == 20 // we only need final predictions
* now we need to place the numbers at the end of each var so we can reshape long:
forv i = 1/6 {
	rename var`i'_pie_ll__top25 var_pie_ll_top25_`i'
	rename var`i'_pie_ul__top25 var_pie_ul_top25_`i'
	rename mid`i'_top25 mid_top25_`i'
	
	rename var`i'_pie_ll__third25 var_pie_ll_third25_`i'
	rename var`i'_pie_ul__third25 var_pie_ul_third25_`i'
	rename mid`i'_third25 mid_third25_`i'
	
	rename var`i'_pie_ll__second25 var_pie_ll_second25_`i'
	rename var`i'_pie_ul__second25 var_pie_ul_second25_`i'
	rename mid`i'_second25 mid_second25_`i'
	
	rename var`i'_pie_ll__lowest25 var_pie_ll_lowest25_`i'
	rename var`i'_pie_ul__lowest25 var_pie_ul_lowest25_`i'
	rename mid`i'_lowest25 mid_lowest25_`i'
}
reshape long var_pie_ll_top25_ var_pie_ul_top25_ mid_top25_ ///
	var_pie_ll_third25_ var_pie_ul_third25_ mid_third25_ ///
	var_pie_ll_second25_ var_pie_ul_second25_ mid_second25_ ///
	var_pie_ll_lowest25_ var_pie_ul_lowest25_ mid_lowest25_, i(time) j(count)
gen pad1 = count - .2
gen pad2 = count - .1
gen pad3 = count + .1
gen pad4 = count + .2

twoway rspike var_pie_ll_lowest25_ var_pie_ul_lowest25_ pad1, horizontal lcolor(black) || ///
	rspike var_pie_ll_second25_ var_pie_ul_second25_ pad2, horizontal lcolor(black) || ///
	rspike var_pie_ll_third25_ var_pie_ul_third25_ pad3, horizontal lcolor(black) || ///
	rspike var_pie_ll_top25_ var_pie_ul_top25_ pad4, horizontal lcolor(black) || ///
	scatter pad1 mid_lowest25_, msymbol(T) mcolor("1 108 89") msize(medlarge) || ///
	scatter pad2 mid_second25_, msymbol(S) mcolor("28 144 153") msize(medlarge) || ///
	scatter pad3 mid_third25_, msymbol(O) mcolor("103 169 207") msize(medlarge) || ///
	scatter pad4 mid_top25_, msymbol(D) mcolor("166 189 219") msize(medlarge) xline(0, lcolor(black) lstyle(solid)) yscale(axis(1) noline) xlabel(, grid glcolor(gs15)) plotregion(style(none)) legend(order(5 "Bottom 25%" 6 "Second 25%" 7 "Third 25%" 8 "Top 25%") ) xtitle("Predicted Proportion")  ylabel(1 "Crime" 2 "Social Welfare" 3 "Intl. Affairs" 4 "Culture" 5 "Other" 6 "Economic Issues", angle(45)) ysize(5)
*graph export "income-stablepredictions.pdf", as(pdf) replace
restore
* --------------------------


* --------------------------
* Figure 11
* a +1SD shock to lunemployment
* --------------------------
su lunemployment
* here's top25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 licb_total nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(1.63) shockvar(lunemployment) saving("dynsimpie_top25")

* here's third 25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 licb_total nixon ford carter reagan hwbush clinton gwbush, dvs($dvs2) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(1.63) shockvar(lunemployment) saving("dynsimpie_third25")

* here's second 25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 licb_total nixon ford carter reagan hwbush clinton gwbush, dvs($dvs3) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(1.63) shockvar(lunemployment) saving("dynsimpie_second25")

* here's lowest 25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 licb_total nixon ford carter reagan hwbush clinton gwbush, dvs($dvs4) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(1.63) shockvar(lunemployment) saving("dynsimpie_lowest25")

* now combine all of them to make SR and LR plots across types:
preserve
use "dynsimpie_top25", clear
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_top25
}
joinby sort using "dynsimpie_third25"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_third25
}
joinby sort using "dynsimpie_second25"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_second25
}
joinby sort using "dynsimpie_lowest25"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_lowest25
}

gen sort_pad1 = sort - .2
gen sort_pad2 = sort - .1
gen sort_pad3 = sort + .1
gen sort_pad4 = sort + .2

$lreplot
*graph export "income-LR-unemployment.pdf", as(pdf) replace
restore

* --------------------------

* --------------------------
* Figure 12
* a +1SD shock to licb_total
* --------------------------
su licb_total // so 1 SD ~ 0.35
* here's top25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.35) shockvar(licb_total) saving("dynsimpie_top25")

* here's third 25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs2) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.35) shockvar(licb_total) saving("dynsimpie_third25")

* here's second 25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs3) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.35) shockvar(licb_total) saving("dynsimpie_second25")

* here's lowest 25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs4) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.35) shockvar(licb_total) saving("dynsimpie_lowest25")

* now combine all of them to make SR and LR plots across types:
preserve
use "dynsimpie_top25", clear
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_top25
}
joinby sort using "dynsimpie_third25"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_third25
}
joinby sort using "dynsimpie_second25"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_second25
}
joinby sort using "dynsimpie_lowest25"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_lowest25
}

gen sort_pad1 = sort - .2
gen sort_pad2 = sort - .1
gen sort_pad3 = sort + .1
gen sort_pad4 = sort + .2

$lreplot
*graph export "income-LR-icb_total.pdf", as(pdf) replace
restore
* --------------------------

* --------------- SI Figure A6: a +1SD shock to icb34_total -----------------
su icb34_total // so 1 SD ~ .22
* here's top25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.22) shockvar(licb34_total) saving("dynsimpie_top25")

* here's third 25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs2) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.22) shockvar(licb34_total) saving("dynsimpie_third25")

* here's second 25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs3) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.22) shockvar(licb34_total) saving("dynsimpie_second25")

* here's lowest 25
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs4) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.22) shockvar(licb34_total) saving("dynsimpie_lowest25")

* now combine all of them to make SR and LR plots across types:
preserve
use "dynsimpie_top25", clear
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_top25
}
joinby sort using "dynsimpie_third25"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_third25
}
joinby sort using "dynsimpie_second25"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_second25
}
joinby sort using "dynsimpie_lowest25"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_lowest25
}

gen sort_pad1 = sort - .2
gen sort_pad2 = sort - .1
gen sort_pad3 = sort + .1
gen sort_pad4 = sort + .2

$lreplot
*graph export "income-LR-icb34_total.pdf", as(pdf) replace
restore



* ----------- SI Table A.3 --------------------------------------------------
* ARIMA models with auto-lag selection across each of our DVs in a SUR setup, include decade (and then presidential) dummies and test whether the decadal dummies differ between income groups

* cap1_4_perc    Top 25%
* cap1_3_perc    third 25%
* cap1_2_perc    Next 25%
* cap1_1_perc    Lowest 25%

* loop through each DV:
set more on
foreach dvnum in 1 11 6 14 19 21 {
	di ""
	di "--------------------------"
	qui sureg (code`dvnum'_1_perc_i l(1/8).code`dvnum'_1_perc_i dec*, nocon) ///
	(code`dvnum'_2_perc_i l(1/8).code`dvnum'_2_perc_i dec*, nocon) ///
	(code`dvnum'_3_perc_i l(1/8).code`dvnum'_3_perc_i dec*, nocon) ///
	(code`dvnum'_4_perc_i l(1/8).code`dvnum'_4_perc_i dec*, nocon)
	cap drop minobs
	qui gen minobs = e(sample)
	* now loop and report back min AIC, run model and test params:
	forv i = 1/8 {
		qui sureg (code`dvnum'_1_perc_i l(1/`i').code`dvnum'_1_perc_i dec*, nocon) ///
		(code`dvnum'_2_perc_i l(1/`i').code`dvnum'_2_perc_i dec*, nocon) ///
		(code`dvnum'_3_perc_i l(1/`i').code`dvnum'_3_perc_i dec*, nocon) ///
		(code`dvnum'_4_perc_i l(1/`i').code`dvnum'_4_perc_i dec*, nocon) ///
		if minobs == 1
		est store model`i'
	}
	qui est table model*, stats(aic)
	minaic
	qui sureg (code`dvnum'_1_perc_i l(1/`r(lag)').code`dvnum'_1_perc_i dec*, nocon) ///
	(code`dvnum'_2_perc_i l(1/`r(lag)').code`dvnum'_2_perc_i dec*, nocon) ///
	(code`dvnum'_3_perc_i l(1/`r(lag)').code`dvnum'_3_perc_i dec*, nocon) ///
	(code`dvnum'_4_perc_i l(1/`r(lag)').code`dvnum'_4_perc_i dec*, nocon)
	di "DV number is: `dvnum'"
	foreach i in 60 70 80 90 00 10 {
		di "Decade is `i', with p-value:"
		qui test _b[code`dvnum'_1_perc_i:dec`i'] = _b[code`dvnum'_2_perc_i:dec`i'] = _b[code`dvnum'_3_perc_i:dec`i'] = _b[code`dvnum'_4_perc_i:dec`i']
		loc roundp = round(r(p), 0.01)
		di "`roundp'"
		
	}
	more
}

* ------------ SI Table A6 --------------------------------------------------
* now repeat, but also including presidential dummies and focusing on those
* loop through each DV:
set more on
foreach dvnum in 1 11 6 14 19 21 {
	di ""
	di "--------------------------"
	* next get min obs so that we're running all models on same data (587 obs so cubed root ~ 8):
	qui sureg (code`dvnum'_1_perc_i l(1/8).code`dvnum'_1_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
	(code`dvnum'_2_perc_i l(1/8).code`dvnum'_2_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
	(code`dvnum'_3_perc_i l(1/8).code`dvnum'_3_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
	(code`dvnum'_4_perc_i l(1/8).code`dvnum'_4_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon)
	cap drop minobs
	qui gen minobs = e(sample)
	* now loop and report back min AIC, run model and test params:
	forv i = 1/8 {
		qui sureg (code`dvnum'_1_perc_i l(1/`i').code`dvnum'_1_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
		(code`dvnum'_2_perc_i l(1/`i').code`dvnum'_2_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
		(code`dvnum'_3_perc_i l(1/`i').code`dvnum'_3_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
		(code`dvnum'_4_perc_i l(1/`i').code`dvnum'_4_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
		if minobs == 1
		est store model`i'
	}
	qui est table model*, stats(aic)
	minaic
	qui sureg (code`dvnum'_1_perc_i l(1/`r(lag)').code`dvnum'_1_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
	(code`dvnum'_2_perc_i l(1/`r(lag)').code`dvnum'_2_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
	(code`dvnum'_3_perc_i l(1/`r(lag)').code`dvnum'_3_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
	(code`dvnum'_4_perc_i l(1/`r(lag)').code`dvnum'_4_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon)
	di "DV number is: `dvnum'"
	foreach var of varlist lbj nixon ford carter reagan hwbush clinton gwbush obama {
		di "Pres term is `var', with p-value:"
		qui test _b[code`dvnum'_1_perc_i:`var'] = _b[code`dvnum'_2_perc_i:`var'] = _b[code`dvnum'_3_perc_i:`var'] = _b[code`dvnum'_4_perc_i:`var']
		loc roundp = round(r(p), 0.01)
		di "`roundp'"
	}
	more
}



